api.authentication.v1.radius.radius_authenticate — Argus-Toolbelt 1.0 documentation

# Source code for api.authentication.v1.radius.radius_authenticate

    """Autogenerated API"""
    import requests
    from argus_cli.plugin import register_command

    @register_command(extending=('authentication','v1','radius','authenticate'))
    def authenticate(userName: str = None, domain: str = None, mode: str = None, password: str = None, tokenCode: str = None, state: str = None,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Initiate a new user session using RADIUS authentication (PUBLIC)
    Requires RADIUS authentication to be enabled on the server, and for the user.
    Use /methods to check which authentication methods are available on the server.

    This is a 2-factor authentication method, which may require additional verification. The first request should have mode AUTHENTICATION, and carry username, password and tokencode.
    If the authentication is challenged, submit a new request with mode CHALLENGE, andinclude the state variable returned in the challenge.

        :param str userName: Username to authenticate
        :param str domain: User domain
        :param str mode: Authentication mode. Use AUTHENTICATION for normal authentication, or CHALLENGE to respond to a challenge request
        :param str password: RADIUS static password
        :param str tokenCode: RADIUS token code
        :param str state: When responding to a challenge, include the encoded state returned by the challenge.
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises NotFoundException: on 404
        :returns: {"offset": 533, "limit": 661, "responseCode": 200, "count": 548, "metaData": {"additionalProperties": {}}, "messages": [{"message": "Wish north enter common quickly receive change.", "messageTemplate": "Also boy exist.", "field": "Blood eye nothing bank add.", "parameter": {}, "timestamp": 1127710350}], "currentPage": 23, "size": 765}
        """
        from requests import post
        from argus_api.exceptions import http

        url = "https://osl-argus-trunk-web1.mnemonic.no/web/api/authentication/v1/radius/authenticate".format()
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if userName:
            body.update({"userName": userName})

        if domain:
            body.update({"domain": domain})

        if mode:
            body.update({"mode": mode})

        if password:
            body.update({"password": password})

        if tokenCode:
            body.update({"tokenCode": tokenCode})

        if state:
            body.update({"state": state})

        response = post(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response